==> pencilbox-1.3.0-src.zip: src/pencilbox/shikaku/Square.java <==
package pencilbox.shikaku;

import pencilbox.common.core.Address;

/**
 * ulpɐ؂vlpNX
 */
public class Square {
	
	static final int NO_NUMBER = 0;
	static final int MULTIPLE_NUMBER = -2;
	private static int NEXT_ID = 1;
	
	private int id;  // ̈ԍ
	
	private int r0;
	private int c0;
	private int r1;
	private int c1;
	private int number; // lp̐
	
	/**
	 * RXgN^
	 * @param ra ̊p̍sW
	 * @param ca ̊p̗W
	 * @param rb ̊p̍sW
	 * @param cb ̊p̗W
	 */
	public Square(int ra, int ca, int rb, int cb) {
		id = NEXT_ID++;
		if (NEXT_ID == Integer.MAX_VALUE) NEXT_ID = 1;
		this.r0 = ra<rb?ra:rb;
		this.c0 = ca<cb?ca:cb;
		this.r1 = ra<rb?rb:ra;
		this.c1 = ca<cb?cb:ca;
	}
	/**
	 * RXgN^
	 * ̎lpƓW̎lp쐬B
	 * @param s lp
	 */
	public Square(Square s) {
		this(s.r0, s.c0, s.r1, s.c1);
	}

	/**
	 * @return the r0
	 */
	public int r0() {
		return r0;
	}
	/**
	 * @return the c0
	 */
	public int c0() {
		return c0;
	}
	/**
	 * @return the r1
	 */
	public int r1() {
		return r1;
	}
	/**
	 * @return the c1
	 */
	public int c1() {
		return c1;
	}
	/**
	 * W̐ݒ
	 * @param ra ̊p̍sW
	 * @param ca ̊p̗W
	 * @param rb ̊p̍sW
	 * @param cb ̊p̗W
	 */
	public void set(int ra, int ca, int rb, int cb) {
		this.r0 = ra<rb?ra:rb;
		this.c0 = ca<cb?ca:cb;
		this.r1 = ra<rb?rb:ra;
		this.c1 = ca<cb?cb:ca;
	}
	
	/**
	 * lp̂S̃}XWCECCȄ̒4̔zɓĕԂB
	 * @return
	 */
	public Address[] getCorners() {
		return new Address[] {new Address(r0, c0), new Address(r0, c1), new Address(r1, c0), new Address(r1, c1)};
	}

	/**
	 * lp1̒_Œ肵܂܁CΊpʒu̒_̍WύXB
	 * @param rOld ύXO̒_̍sW
	 * @param cOld ύXO̒_̍sW
	 * @param rNew ύX̒_̍sW
	 * @param cNew ύX̒_̍sW
	 */
	public void changeCorner(int rOld, int cOld, int rNew, int cNew) {
		int ra = this.r0;
		int ca = this.c0;
		int rb = this.r1;
		int cb = this.c1;
		if (ra == rOld) {
			ra = rNew;
		} else if (rb == rOld) {
			rb = rNew;
		}
		if (ca == cOld) {
			ca = cNew;
		} else if (cb == cOld) {
			cb = cNew;
		}
		this.set(ra, ca, rb, cb);
	}

	/**
	 * `̖̈ʐςԂ
	 * @return ̖̈ʐ
	 */
	public int getSquareSize() {
		return (r1-r0+1) * (c1-c0+1);
	}
	
	public String toString() {
		return "["+r0+","+c0+","+r1+","+c1+"]";
	}
	/**
	 * @return 
	 */
	public int getNumber() {
		return number;
	}

	/**
	 * @param i
	 */
	public void setNumber(int i) {
		number = i;
	}
	/**
	 * @return Returns the id.
	 */
	public int getId() {
		return id;
	}

}

==> pencilbox-1.4.1-src.zip: src/pencilbox/shikaku/Square.java <==
package pencilbox.shikaku;

import pencilbox.common.core.Address;

/**
 * ulpɐ؂vlpNX
 */
public class Square {
	
	static final int NO_NUMBER = 0;
	static final int MULTIPLE_NUMBER = -2;
	private static int NEXT_ID = 1;
	
	private int id;  // ̈ԍ
	
	private int r0;
	private int c0;
	private int r1;
	private int c1;
	private int number; // lp̐
	
	/**
	 * RXgN^
	 * @param ra ̊p̍sW
	 * @param ca ̊p̗W
	 * @param rb ̊p̍sW
	 * @param cb ̊p̗W
	 */
	public Square(int ra, int ca, int rb, int cb) {
		id = NEXT_ID++;
		if (NEXT_ID == Integer.MAX_VALUE) NEXT_ID = 1;
		this.r0 = ra<rb?ra:rb;
		this.c0 = ca<cb?ca:cb;
		this.r1 = ra<rb?rb:ra;
		this.c1 = ca<cb?cb:ca;
	}
	/**
	 * RXgN^
	 * @param posA ̊p̍W
	 * @param posB ̊p̍W
	 */
	public Square(Address posA, Address posB) {
		this(posA.r(), posA.c(), posB.r(), posB.c());
	}
	/**
	 * RXgN^
	 * ̎lpƓW̎lp쐬B
	 * @param s lp
	 */
	public Square(Square s) {
		this(s.r0, s.c0, s.r1, s.c1);
	}

	/**
	 * @return the r0
	 */
	public int r0() {
		return r0;
	}
	/**
	 * @return the c0
	 */
	public int c0() {
		return c0;
	}
	/**
	 * @return the r1
	 */
	public int r1() {
		return r1;
	}
	/**
	 * @return the c1
	 */
	public int c1() {
		return c1;
	}
	/**
	 * W̐ݒ
	 * @param ra ̊p̍sW
	 * @param ca ̊p̗W
	 * @param rb ̊p̍sW
	 * @param cb ̊p̗W
	 */
	public void set(int ra, int ca, int rb, int cb) {
		this.r0 = ra<rb?ra:rb;
		this.c0 = ca<cb?ca:cb;
		this.r1 = ra<rb?rb:ra;
		this.c1 = ca<cb?cb:ca;
	}
	
	/**
	 * lp̂S̃}XWCECCȄ̒4̔zɓĕԂB
	 * @return
	 */
	public Address[] getCorners() {
		return new Address[] {new Address(r0, c0), new Address(r0, c1), new Address(r1, c0), new Address(r1, c1)};
	}

	/**
	 * lp1̒_Œ肵܂܁CΊpʒu̒_̍WύXB
	 * @param rOld ύXO̒_̍sW
	 * @param cOld ύXO̒_̍sW
	 * @param rNew ύX̒_̍sW
	 * @param cNew ύX̒_̍sW
	 */
	public void changeCorner(int rOld, int cOld, int rNew, int cNew) {
		int ra = this.r0;
		int ca = this.c0;
		int rb = this.r1;
		int cb = this.c1;
		if (ra == rOld) {
			ra = rNew;
		} else if (rb == rOld) {
			rb = rNew;
		}
		if (ca == cOld) {
			ca = cNew;
		} else if (cb == cOld) {
			cb = cNew;
		}
		this.set(ra, ca, rb, cb);
	}

	/**
	 * `̖̈ʐςԂ
	 * @return ̖̈ʐ
	 */
	public int getSquareSize() {
		return (r1-r0+1) * (c1-c0+1);
	}
	
	public String toString() {
		return "["+r0+","+c0+","+r1+","+c1+"]";
	}
	/**
	 * @return 
	 */
	public int getNumber() {
		return number;
	}

	/**
	 * @param i
	 */
	public void setNumber(int i) {
		number = i;
	}
	/**
	 * @return Returns the id.
	 */
	public int getId() {
		return id;
	}

}
